@@ -6,12 +6,14 @@
  * which will appear 1995 at Saarbruecken University, Germany.
  * Jochen's contribution is greatly appreciated.
  * ---- Christoph W. Kessler, in March 1995.
+ *
+ * rwd_lock is a new lock type added in March 1999.
  */
 
 /* 
  * Implementation of a locking mechanism
  * simple, fair and safe locks: -> forklib2.asm
- * reader-writer-locks: here
+ * reader-writer-locks and reader-writer-deleter-locks: here
  *
  * Implementation of counting barrier synchronization ->forklib2.asm
  *
@@ -25,16 +27,18 @@
 #include <fork.h>
 #include <io.h>
 
+#define REPORT_LOCKUP_UNLOCK 0    // if 1, print debug info to stdout
+
 pr int __mp_dummyvar;   /* bugfix to make multipraefix work properly */
 
-simple_lock *new_simple_lock( void )
+simple_lock *new_SimpleLock( void )
 {
   simple_lock *ret = (simple_lock *)shmalloc( sizeof( simple_lock ));
   *ret = 0;
   return ret;
 }
 
-fair_lock *new_fair_lock( void )
+fair_lock *new_FairLock( void )
 {
   fair_lock *ret = (fair_lock *)shmalloc( sizeof( fair_lock ));
   ret->nextnum = ret->actnum = 0;
@@ -85,7 +89,7 @@ void rw_lock_init( rw_lock *lock)
    lock->writerlock.actnum = 0;    /* init fair lock */
 }
 
-rw_lock *new_rw_lock( void )
+rw_lock *new_RWLock( void )
 {
   rw_lock *ret = (rw_lock *)shmalloc( sizeof( rw_lock ));
   ret->readercounter = 0;
@@ -138,9 +142,8 @@ void rw_lockup( rw_lock *lock, int ptype)
 
 void rw_unlock( rw_lock *lock, int ptype, int wait)
 {
- int dummy;
  if(ptype == RW_READ)    /* reader-unlock */
-    dummy = mpadd ( &(lock->readercounter), -1);
+    mpadd ( &(lock->readercounter), -1);
  else {   /* writer-unlock */
     int i;
     /* free lock for readers */
@@ -164,7 +167,7 @@ void rwd_lock_init( rwd_lock *lock)
    lock->deleteflag = 0;
 }
 
-rwd_lock *new_rwd_lock( void )
+rwd_lock *new_RWDLock( void )
 {
   rwd_lock *ret = (rwd_lock *)shmalloc( sizeof( rwd_lock ));
   ret->readercounter = 0;
@@ -178,8 +181,10 @@ rwd_lock *new_rwd_lock( void )
 int rwd_lockup( rwd_lock *lock, int ptype)
 {
  int wait;
+#if REPORT_LOCKUP_UNLOCK
  pprintf("call rwd_lockup( %p, %s )\n", lock, (ptype==RW_READ)?"RW_READ":
           (ptype==RW_WRITE)?"RW_WRITE":"RW_DELETE");
+#endif
  if(ptype == RW_READ) {         /* reader-lock */
     wait = 1; /* wait = TRUE */
     while(wait) {
@@ -196,7 +201,9 @@ int rwd_lockup( rwd_lock *lock, int ptype)
           wait = 1; /* wait = TRUE */
        }
     }
+#if REPORT_LOCKUP_UNLOCK
     pprintf("rwd_lockup( %p, RW_READ ) succeeded\n", lock );
+#endif
  }
  else {      /* writer-lock */
     /* wait for writer to leave the lock */
@@ -210,7 +217,9 @@ int rwd_lockup( rwd_lock *lock, int ptype)
     if (ptype == RW_DELETE) {
        lock->deleteflag = 1;   /*stg at mo=1, all other accesses ldg at mo=0*/
     }
+#if REPORT_LOCKUP_UNLOCK
     pprintf("rwd_lockup( %p, %s ) succeeded\n", lock, (ptype==RW_WRITE)?"RW_WRITE":"RW_DELETE");
+#endif
  }
  return 1;
 } /* rwd_lockup() */
@@ -218,8 +227,10 @@ int rwd_lockup( rwd_lock *lock, int ptype)
 
 void rwd_unlock( rwd_lock *lock, int ptype, int wait)
 {
+#if REPORT_LOCKUP_UNLOCK
  pprintf("rwd_unlock( %p, %s )\n", lock, (ptype==RW_READ)?"RW_READ":
           (ptype==RW_WRITE)?"RW_WRITE":"RW_DELETE");
+#endif
  if(ptype == RW_READ)    /* reader-unlock */
     mpadd ( &(lock->readercounter), -1);
  else {   /* writer-unlock */
