@@ -94,10 +94,14 @@ void prstat( void ) {
 }
 
 
-void printAccStat( void )         /* 990119*/
+void printAccStat( void )         /*990119*/
 {
+  extern int _barrWaitTime;  /*990504*/
+
   write(1,"AccStat for P", 13); prI(__PROC_NR__,0); write(1,": passed ",9);
-  prI(_barrcnt,0); write(1," barriers,\n                ",27);
+  prI(_barrcnt,0); write(1," barriers, waited ", 18);
+  prI(_barrWaitTime>>8,0);
+  write(1," msecs,\n                ",25);
   prI(_myshldgcnt,0); write(1," of ",4);
   prI(_shldgcnt,0); write(1," sh-loads,\t",11);
   prI(_myshstgcnt,0); write(1," of ",4);
@@ -701,9 +705,9 @@ int fclose ( FILE *fp )
  assert( fp );
  errcode = close (fp->fd);
  if (!errcode) {
-    free( fp->buffer );
+    shfree( fp->buffer );
     __iob[fp->fd] = NULL;
-    free( fp );
+    FILEFREE( fp );
  }
  return errcode;
 }
