@@ -5,10 +5,7 @@
 #include <assert.h>
 #include <io.h>
 
-#define SCREENCOLS 80  /* number of columns on my screen */
-
 sh int N;            /* the number of queens */
-pr int BOARDS_PER_ROW;
 
 sh simple_lock screen = 0;  /*lock for screen output*/
 
@@ -64,15 +61,22 @@ async void print_up_to_eight_solutions( pr int *q, pr int n, pr int k )
 {
  pr int j;
  pr int waittime = 0; /* last set of solutions must be printed also if p<8*/
- BOARDS_PER_ROW = (SCREENCOLS - N) / N;
-#define maxtime 1000    /*empirically determined value for waiting time*/
- join( 0,                                   /*join ID*/ 
+#define maxtime 300    /*empirically determined value for waiting time*/
+#if USE_JOIN_MACRO
+ JOIN( 0,                                   /*join ID*/ 
        while(_ticket[0]<8 && (waittime++ < maxtime)), /*delay stmt*/
-       $ >= BOARDS_PER_ROW,                 /*springoff condition*/ 
+       $ >= 8,                              /*springoff condition*/ 
        400,                                 /*stack space for body*/
        1,                                   /*retry if missed*/
        print_p_solutions(q,n,k),            /*body = bus tour*/
      );                                     /*empty else branch*/
+#else
+ join( 400;                                       /* stack size for body */
+       (__NUM_PR__>=4 || (waittime++ > maxtime)); /* start-condition */
+       __RANK__ < 8 )                             /* stayinside-cond */
+      print_p_solutions(q,n,k);            /*body = bus tour*/
+ else continue;
+#endif
 }
 
 
@@ -91,7 +95,7 @@ void seq_test_queen( int *q, int n, int j )
  /* now position j is feasible.*/
 
  if (n<N-1) { /* not yet arrived at last row: */
-    qq = (int *)shmalloc( n+1 );
+    qq = (int *)malloc( n+1 );
     for (l=0; l<n; l++) qq[l] = q[l]; /* make copy of q */
     qq[n]=j;  /* as computed above */
     for (i=0; i<N; i++) {   /* try all column indices i */
@@ -101,14 +105,9 @@ void seq_test_queen( int *q, int n, int j )
       if (thr || (i==j)) continue;  /*column i threatened by a queen */
       seq_test_queen( qq, n+1, i );  /* recursive call for row n+1 */
     }
-    shfree( qq );  /*990126*/
  }
  else  /* final row */
-#if 1
     print_up_to_eight_solutions( q, N-1, j );
-#else
-    print_queens( q, N-1, j );
-#endif
 } 
 
 /* assume queens in row 0...n-1 have been set, 
@@ -170,13 +169,7 @@ sync void test_queen( sh int *q, sh int n, sh int j )
  } 
 
  else  /* arrived at last row: print the solution */
-    farm
-      if($==0) 
-#if 0
-        print_up_to_eight_solutions( q, N-1, j );
-#else
-        print_queens( q, N-1, j );
-#endif
+    farm if($==0) print_up_to_eight_solutions( q, N-1, j );
 }
 
 sh unsigned int starttime, stoptime;
@@ -205,7 +198,7 @@ void main( void )
  }
  barrier;
  simple_lockup( &screen );
-  printAccStat();
+   printAccStat();
  simple_unlock( &screen );
  barrier; exit(0);
 }
