@@ -239,10 +239,17 @@ static Symbol dcllocal(sclass, styp, id, ty, pos, sy) char *id; Type ty; Coordin
    if (isfunc(ty) && ty->u.proto && *(ty->u.proto)) {  /*CWK*/
       p->sharedparameters = (*(ty->u.proto))->sharedparams;   /*CWK*/
       p->regparameters = (*(ty->u.proto))->regparams;         /*CWK*/
+      if (sy==ASYNCF && p->sharedparameters)
+        error("asynchronous function must not have shared parameters\n");
    }  /*else bleibts bei beiden 0 */
    p->sclass = sclass;
-   /*if (ty && isptr(ty) && isfunc(ty->type))  *CWK*
-     p->shared = (ty->sharity==1)? 1:0; else */
+   if (ty && isptr(ty) && isfunc(ty->type)) {  // 990611
+      if (*(ty->type->u.proto)) { // 990611
+         p->sharedparameters = (*(ty->type->u.proto))->sharedparams;
+         if (sy==ASYNCF && p->sharedparameters)
+            error("asynchronous function must not have shared parameters\n");
+      }
+   }
    p->shared = (styp==SHARED)? 1:0; /*CWK*/
    p->sync = (sy==SYNCF)? 1:0;
    if (p->shared)
@@ -364,6 +371,14 @@ static Symbol dclparam(sclass, styp, id, ty, pos, sy) char *id; Type ty; Coordin
       p->sharedparameters = (*(ty->u.proto))->sharedparams;   /*CWK*/
       p->regparameters = (*(ty->u.proto))->regparams;         /*CWK*/
    }  /*else bleibts bei beiden 0 */
+   // new 990611:  (fix just one more level - no general recursive descend!)
+   if (ty && isptr(ty) && isfunc(ty->type)) {  // 990611
+      if (*(ty->type->u.proto)) { // 990611
+         p->sharedparameters = (*(ty->type->u.proto))->sharedparams;
+         if (sy==ASYNCF && p->sharedparameters)
+            error("asynchronous function must not have shared parameters\n");
+      }
+   }
    if (sclass == 0)
       sclass = AUTO;
    if (sclass == REGISTER && ty && (isvolatile(ty) || isstruct(ty))) {
@@ -875,6 +890,7 @@ static void funcdecl(sclass, styp, id, ty, pt, sy) char *id; Type ty; Coordinate
    cfunc = dclglobal(sclass, styp, id, ty, &pt, sy); /*CWK*/
    if (sy==ASYNCF) { cfunc->sync = 0; }  /*CWK*/
    else            { cfunc->sync = 1; }
+   cfunc->nreturns = 0;    /* 990525 */
    cfunc->u.f.pt[0] = pt;
    if (JUMP_ON_RETURN || glevel > 1)
       cfunc->u.f.label = genlabel(1);
@@ -901,6 +917,7 @@ static void funcdecl(sclass, styp, id, ty, pt, sy) char *id; Type ty; Coordinate
       if (freturn(cfunc->type) != voidtype
       && (freturn(cfunc->type) != inttype || Aflag >= 1))
          warning("missing return value\n");
+      cfunc->nreturns ++;  /*990525*/
       retcode(0, 0, 0);   /*CWK: no frames open at end of function*/
    }
    if (cfunc->u.f.label) {
@@ -908,6 +925,9 @@ static void funcdecl(sclass, styp, id, ty, pt, sy) char *id; Type ty; Coordinate
       definept(0);
       walk(0, 0, 0);
    }
+   print("\n");
+   /* print("// %s Fn. %s nreturns: %d\n", (cfunc->sync)?"sy.":"asy.", 
+            cfunc->name, cfunc->nreturns); */
    exitscope();
    foreach(identifiers, level, checkref, (Generic)0);
    flushequ();
@@ -1196,7 +1216,8 @@ static Type tnode(op, type) Type type; {
       ty->sharedparams = type->sharedparams;
       ty->regparams = type->regparams;
    }
-   else ty->sharedparams = ty->regparams = 0;
+   else 
+        ty->sharedparams = ty->regparams = 0;
    return ty;
 }
 
