@@ -127,6 +127,7 @@ static Tree call(f, fty, src) Tree f; Type fty; Coordinate src; {
        sharedpar = f->u.sym->sharedparameters;    /*CWK*/
        regpar = f->u.sym->regparameters;    /*CWK*/
        issync = f->u.sym->sync;           /*CWK*/
+       //fprint( 2, "====== %s: sharedpar = %d\n", f->u.sym->name, sharedpar);
    }
    else 
      if (isptr(f->type) && isfunc(f->type->type)) {
@@ -137,7 +138,16 @@ static Tree call(f, fty, src) Tree f; Type fty; Coordinate src; {
        symb = myf->u.sym;
        assert(symb); /*970811*/ /* oben eingebaut in Abfrage 950522*/
        if (symb) {
+#if 0
+         if (f->type->type->u.proto && (*(f->type->type->u.proto))) { // 990611
+            sharedpar = (*(f->type->type->u.proto))->sharedparams;
+            fprint( 2, ">>>>>> %s: sharedpar = %d (was: %d)\n",
+                       symb->name, sharedpar, symb->sharedparameters);
+         }
+         else  // so war's vorher:
+#endif
          sharedpar = symb->sharedparameters;    /*CWK*/
+         //fprint( 2, "###### %s: sharedpar = %d\n", symb->name, sharedpar);
          regpar = symb->regparameters;    /*CWK*/
          issync = symb->sync;
        }
