@@ -13,6 +13,7 @@ char **src, *tolink = "";
 int srcs = 0;
 int Eflag=0;
 int Sflag=0;
+int Tflag=0;
 int cflag=0;
 int vflag=0;
 
@@ -46,6 +47,9 @@ void doargs(argc,argv)
                  break;
        case 'S': Sflag = 1;   /*behalte .s-Files*/
                  break;
+       case 'T': Tflag = 1; /*990504: generate profiling code*/
+                 compopts = append(compopts, s);
+                 break;
        case 'o': /* -o outfilename: */
                  linkopts = append(linkopts, s);
                  s = argv[++i];
@@ -165,10 +169,11 @@ main(argc,argv)
   lnks = linkfiles(src,srcs);
   if (!lnks) exit(1);
   
-  sprintf(plink,"%s %s %s %s/forklib2.o \
+  sprintf(plink,"%s %s %s %s/%s \
    %s/stdlib.o %s/graphic.o %s/string.o %s/ctype.o %s/io.o %s/print.o %s/async.o %s/join.o \
    %s/math.o %s", 
-                 thelinker, linkopts, lnks, thelibdir,               thelibdir,
+                 thelinker, linkopts, lnks, thelibdir, 
+   (Tflag)?"forklib2.o" : "forklib.o",              thelibdir,
    thelibdir, thelibdir, thelibdir, thelibdir, thelibdir, thelibdir, thelibdir, thelibdir, 
    Umlenkung);
   if (vflag) printf("%s\n", plink);
