@@ -250,7 +250,23 @@ typedef enum opcode {
    ENDSEQV=(68<<4)+V,
    SHSPACE=69<<4,
    SHSPACEV=(69<<4)+V,
-   MAXOP=70<<4, /*CWK vormals 38<<4*/
+   JBLOCKa=70<<4,
+   JBLOCKaV=(70<<4)+V,
+   JBLOCKb=71<<4,
+   JBLOCKbV=(71<<4)+V,
+   JBLOCKc=72<<4,
+   JBLOCKcV=(72<<4)+V,
+   JBLOCKd=73<<4,
+   JBLOCKdV=(73<<4)+V,
+   JBLOCKe=74<<4,
+   JBLOCKeV=(74<<4)+V,
+   JBLOCKf=75<<4,
+   JBLOCKfV=(75<<4)+V,
+   JBLOCKg=76<<4,
+   JBLOCKgV=(76<<4)+V,
+   JBLOCKh=77<<4,
+   JBLOCKhV=(77<<4)+V,
+   MAXOP=78<<4, /*CWK vormals 38<<4*/
    /* additional tree operators: */
    AND=MAXOP,
    NOT=MAXOP+1*16,
