@@ -237,6 +237,8 @@ int eqtype(ty1, ty2, ret) Type ty1, ty2; {
             }
             return 1;
          }
+         if ((*p1)->sharedparams != (*p2)->sharedparams)
+             warning("shared parameter declarations do not match");
          for ( ; *p1 && *p2; p1++, p2++)
             if (eqtype(unqual(*p1), unqual(*p2), ret) == 0)
 /*            if (eqtype(*p1, *p2, ret) == 0) */
